#!/bin/csh

if (`flagLoc $argv -help`) then
   echo "Split 2D NMRPipe-format Data into a 1D Series:"
   echo " -in      inName  [test.fid]      2D Input Name."
   echo " -outDir  outDir  [dat]           Output Directory."
   echo " -outName outName [test%03d.dat]  Output Name Template."
   echo " -tau     tList   [0.0 ...]       Optional List of Tau Values."
   exit 0
endif

set inName  = (`getArgD $argv -in      test.fid`)
set outDir  = (`getArgD $argv -outDir  dat`)
set outName = (`getArgD $argv -outName test.%03d.dat`)

set tauList = (`getListArgD $argv -tau -- 0.0`)

#
#------------------------------------------------------------------------

if (!(-e $inName)) then
   echo Error finding 2D Input $inName
   exit 1
endif

if (!(-d $outDir)) then
   mkdir $outDir 
endif

set ne = (`getParm -in $inName -parm NDSIZE -dim Y -fmt %.0f`)

set cList   = 0
set tauList = 0

#
# Create initial cList of 0.0 ...
# Add values to optional tau list to be sure it is always long enough.

echo "Creating $ne 1D from $inName"

set i = 1

while ($i < $ne)
   set cList = ($cList 0)
   set tauList = ($tauList $i)
   @ i++
end

#
# Extract each 1D slice.
# Update header.

set i = 1

while ($i <= $ne)
   set thisName =  (`printf $outDir/$outName $i`)
   set cList[$i] = 1

   echo " $i. $thisName Tau: $tauList[$i]"

   nmrPipe -in $inName \
   | nmrPipe -fn COADD -axis Y -cList $cList \
   -out $thisName -ov

   set cList[$i]   = 0

   sethdr $thisName -ndim 1 -tau $tauList[$i]

   @ i++
end

